const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const AssetsPlugin = require("assets-webpack-plugin");
const path = require("path");
const glob = require("glob");
const entryPoints = glob.sync("./src/EntryPoints/**.ts").reduce(function (obj, el) {
  obj[path.parse(el).name] = el;
  return obj;
}, {});
module.exports = {
  entry: entryPoints,
  output: {
    path: path.join(__dirname, "build"),
    filename: "[name].js",
    publicPath: "./",
    libraryTarget: "commonjs2",
  },
  plugins: [
    new AssetsPlugin({
      filename: "webpack.assets.json",
      path: "./build",
      prettyPrint: true,
      includeAllFileTypes: false,
    }),
    new MiniCssExtractPlugin(),
  ],
  module: {
    rules: [
      { test: /\.js$/, exclude: /node_modules/, use: ["babel-loader"] },
      {
        test: /\.(sa|sc|c)ss$/,
        use: [
          {
            loader: MiniCssExtractPlugin.loader,
            options: {
              hmr: process.env.NODE_ENV === "development",
            },
          },
          "css-loader",
          "sass-loader",
        ],
      },
      { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, use: "file-loader" },
      {
        test: /\.(woff|woff2)(\?v=\d+\.\d+\.\d+)?$/,
        use: "url-loader?-loaderprefix=font/&limit=5000",
      },
      {
        test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/,
        use: "url-loader?limit=10000&mimetype=application/octet-stream",
      },
      {
        test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
        use: "url-loader?limit=10000&mimetype=image/svg+xml",
      },
      { test: /\.(jpe?g|png|gif|svg)$/, use: "file-loader" },
      {
        enforce: "pre",
        test: /\.tsx?$/,
        exclude: /node_modules/,
        use: "babel-loader",
      },
    ],
  },
  externals: {
    react: "commonjs react",
  },
  resolve: {
    alias: {
      src: path.resolve(__dirname, "src"),
      Utilities: path.resolve(__dirname, "src/Utilities"),
    },
    extensions: [".tsx", ".ts", ".js", ".jsx", ".scss", ".css"],
  },
};
