const webpack = require("webpack");
const webpackMerge = require("webpack-merge");
const Visualizer = require("webpack-visualizer-plugin");
const WebpackNotifierPlugin = require("webpack-notifier");
const baseConfig = require("./webpack.config.base");

const mode = "development";
const GLOBALS = {
  "process.env.NODE_ENV": JSON.stringify(mode),
  APP_VERSION: JSON.stringify(require("./package.json").version),
};

module.exports = webpackMerge(baseConfig, {
  mode,
  devtool: "source-map",
  stats: "minimal",
  optimization: {
    // Don't create the bundle if it errors in production
    noEmitOnErrors: false,
    // Minimize only in production
    minimize: false,
  },
  plugins: [
    new webpack.ProgressPlugin(),
    new webpack.ProgressPlugin((percentage, message, ...desc) => {
      if (percentage === 1) {
        const date = new Date();
        console.log(`[${date.getHours()}:${date.getMinutes()}:${date.getSeconds()}]:🍺 Complete!`);
      }
    }),
    new WebpackNotifierPlugin(),
    new webpack.LoaderOptionsPlugin({
      debug: true,
    }),
    new Visualizer(),
    new webpack.DefinePlugin(GLOBALS),
  ],
  module: {
    rules: [
      {
        enforce: "pre",
        test: /\.[jt]sx?$/,
        exclude: /node_modules/,
        loader: "eslint-loader",
        options: {
          fix: true,
        },
      },
    ],
  },
});
